/*
 * custom.css
 * ~~~~~~~~~
 *
 * Custom stylesheet
 *
 */

.sphinxsidebar .caption-text {
    font-size: 120%;
}

.logo {
    width: 100%;
}

.sphinxsidebarwrapper .internal {
    font-weight: bold;
}
